# ospyata

Python bindings for osmata

[![Open in Visual Studio Code](https://open.vscode.dev/badges/open-in-vscode.svg)](https://open.vscode.dev/aerocyber/ospyata)

## Docs

Documentation is present in the [Docs](docs/index.md) directory.
